@@ -1,26 +1,32 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Schema;
 
+use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\Platforms\AbstractMySQLPlatform;
-use Doctrine\DBAL\Platforms\MariaDb1027Platform;
+use Doctrine\DBAL\Platforms\MariaDBPlatform;
 use Doctrine\DBAL\Platforms\MySQL;
+use Doctrine\DBAL\Platforms\MySQL\CharsetMetadataProvider\CachingCharsetMetadataProvider;
+use Doctrine\DBAL\Platforms\MySQL\CharsetMetadataProvider\ConnectionCharsetMetadataProvider;
 use Doctrine\DBAL\Platforms\MySQL\CollationMetadataProvider\CachingCollationMetadataProvider;
 use Doctrine\DBAL\Platforms\MySQL\CollationMetadataProvider\ConnectionCollationMetadataProvider;
+use Doctrine\DBAL\Platforms\MySQL\DefaultTableOptions;
 use Doctrine\DBAL\Result;
 use Doctrine\DBAL\Types\Type;
-use Doctrine\Deprecations\Deprecation;
 
 use function array_change_key_case;
-use function array_shift;
+use function array_map;
 use function assert;
 use function explode;
+use function func_get_arg;
+use function func_num_args;
 use function implode;
-use function is_string;
 use function preg_match;
-use function strpos;
-use function strtok;
-use function strtolower;
+use function preg_match_all;
+use function sprintf;
+use function str_contains;
 use function strtr;
 
 use const CASE_LOWER;
@@ -50,170 +56,86 @@ class MySQLSchemaManager extends AbstractSchemaManager
         "''" => "'",
     ];
 
-    /**
-     * {@inheritDoc}
-     */
-    public function listTableNames()
-    {
-        return $this->doListTableNames();
-    }
+    private ?DefaultTableOptions $defaultTableOptions = null;
 
     /**
-     * {@inheritDoc}
-     */
-    public function listTables()
-    {
-        return $this->doListTables();
-    }
-
-    /**
-     * {@inheritDoc}
+     * @deprecated Use the schema name and the unqualified table name separately instead.
      *
-     * @deprecated Use {@see introspectTable()} instead.
+     * {@inheritDoc}
      */
-    public function listTableDetails($name)
+    protected function _getPortableTableDefinition(array $table): string
     {
-        Deprecation::trigger(
-            'doctrine/dbal',
-            'https://github.com/doctrine/dbal/pull/5595',
-            '%s is deprecated. Use introspectTable() instead.',
-            __METHOD__,
-        );
-
-        return $this->doListTableDetails($name);
+        return $table['TABLE_NAME'];
     }
 
     /**
      * {@inheritDoc}
      */
-    public function listTableColumns($table, $database = null)
-    {
-        return $this->doListTableColumns($table, $database);
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    public function listTableIndexes($table)
-    {
-        return $this->doListTableIndexes($table);
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    public function listTableForeignKeys($table, $database = null)
-    {
-        return $this->doListTableForeignKeys($table, $database);
-    }
-
-    /**
-     * {@inheritdoc}
-     */
-    protected function _getPortableViewDefinition($view)
+    protected function _getPortableViewDefinition(array $view): View
     {
         return new View($view['TABLE_NAME'], $view['VIEW_DEFINITION']);
     }
 
     /**
-     * {@inheritdoc}
+     * {@inheritDoc}
      */
-    protected function _getPortableTableDefinition($table)
+    protected function _getPortableTableIndexesList(array $rows, string $tableName): array
     {
-        return array_shift($table);
-    }
+        foreach ($rows as $i => $row) {
+            $row = array_change_key_case($row, CASE_LOWER);
 
-    /**
-     * {@inheritdoc}
-     */
-    protected function _getPortableTableIndexesList($tableIndexes, $tableName = null)
-    {
-        foreach ($tableIndexes as $k => $v) {
-            $v = array_change_key_case($v, CASE_LOWER);
-            if ($v['key_name'] === 'PRIMARY') {
-                $v['primary'] = true;
-            } else {
-                $v['primary'] = false;
-            }
+            $row['primary'] = $row['key_name'] === 'PRIMARY';
 
-            if (strpos($v['index_type'], 'FULLTEXT') !== false) {
-                $v['flags'] = ['FULLTEXT'];
-            } elseif (strpos($v['index_type'], 'SPATIAL') !== false) {
-                $v['flags'] = ['SPATIAL'];
+            if (str_contains($row['index_type'], 'FULLTEXT')) {
+                $row['flags'] = ['FULLTEXT'];
+            } elseif (str_contains($row['index_type'], 'SPATIAL')) {
+                $row['flags'] = ['SPATIAL'];
             }
 
             // Ignore prohibited prefix `length` for spatial index
-            if (strpos($v['index_type'], 'SPATIAL') === false) {
-                $v['length'] = isset($v['sub_part']) ? (int) $v['sub_part'] : null;
+            if (! str_contains($row['index_type'], 'SPATIAL')) {
+                $row['length'] = isset($row['sub_part']) ? (int) $row['sub_part'] : null;
             }
 
-            $tableIndexes[$k] = $v;
+            $rows[$i] = $row;
         }
 
-        return parent::_getPortableTableIndexesList($tableIndexes, $tableName);
+        return parent::_getPortableTableIndexesList($rows, $tableName);
     }
 
     /**
-     * {@inheritdoc}
+     * {@inheritDoc}
      */
-    protected function _getPortableDatabaseDefinition($database)
+    protected function _getPortableDatabaseDefinition(array $database): string
     {
         return $database['Database'];
     }
 
     /**
-     * {@inheritdoc}
+     * {@inheritDoc}
      */
-    protected function _getPortableTableColumnDefinition($tableColumn)
+    protected function _getPortableTableColumnDefinition(array $tableColumn): Column
     {
         $tableColumn = array_change_key_case($tableColumn, CASE_LOWER);
 
-        $dbType = strtolower($tableColumn['type']);
-        $dbType = strtok($dbType, '(), ');
-        assert(is_string($dbType));
-
-        $length = $tableColumn['length'] ?? strtok('(), ');
-
-        $fixed = null;
-
-        if (! isset($tableColumn['name'])) {
-            $tableColumn['name'] = '';
-        }
-
-        $scale     = null;
+        $dbType    = $tableColumn['type'];
+        $length    = null;
+        $scale     = 0;
         $precision = null;
+        $fixed     = false;
+        $values    = [];
 
-        $type = $this->_platform->getDoctrineTypeMapping($dbType);
-
-        // In cases where not connected to a database DESCRIBE $table does not return 'Comment'
-        if (isset($tableColumn['comment'])) {
-            $type                   = $this->extractDoctrineTypeFromComment($tableColumn['comment'], $type);
-            $tableColumn['comment'] = $this->removeDoctrineTypeFromComment($tableColumn['comment'], $type);
-        }
+        $type = $this->platform->getDoctrineTypeMapping($dbType);
 
         switch ($dbType) {
             case 'char':
-            case 'binary':
-                $fixed = true;
+            case 'varchar':
+                $length = (int) $tableColumn['character_maximum_length'];
                 break;
 
-            case 'float':
-            case 'double':
-            case 'real':
-            case 'numeric':
-            case 'decimal':
-                if (
-                    preg_match(
-                        '([A-Za-z]+\(([0-9]+),([0-9]+)\))',
-                        $tableColumn['type'],
-                        $match,
-                    ) === 1
-                ) {
-                    $precision = $match[1];
-                    $scale     = $match[2];
-                    $length    = null;
-                }
-
+            case 'binary':
+            case 'varbinary':
+                $length = (int) $tableColumn['character_octet_length'];
                 break;
 
             case 'tinytext':
@@ -240,55 +162,72 @@ class MySQLSchemaManager extends AbstractSchemaManager
                 $length = AbstractMySQLPlatform::LENGTH_LIMIT_MEDIUMBLOB;
                 break;
 
-            case 'tinyint':
-            case 'smallint':
-            case 'mediumint':
-            case 'int':
-            case 'integer':
-            case 'bigint':
-            case 'year':
-                $length = null;
+            case 'float':
+            case 'double':
+            case 'real':
+            case 'numeric':
+            case 'decimal':
+                $precision = (int) $tableColumn['numeric_precision'];
+
+                if (isset($tableColumn['numeric_scale'])) {
+                    $scale = (int) $tableColumn['numeric_scale'];
+                }
+
                 break;
         }
 
-        if ($this->_platform instanceof MariaDb1027Platform) {
-            $columnDefault = $this->getMariaDb1027ColumnDefault($this->_platform, $tableColumn['default']);
+        switch ($dbType) {
+            case 'char':
+            case 'binary':
+                $fixed = true;
+                break;
+
+            case 'enum':
+                $values = $this->parseEnumExpression($tableColumn['column_type']);
+                break;
+        }
+
+        if ($this->platform instanceof MariaDBPlatform) {
+            $columnDefault = $this->getMariaDBColumnDefault($this->platform, $tableColumn['default']);
         } else {
             $columnDefault = $tableColumn['default'];
         }
 
         $options = [
-            'length'        => $length !== null ? (int) $length : null,
-            'unsigned'      => strpos($tableColumn['type'], 'unsigned') !== false,
-            'fixed'         => (bool) $fixed,
+            'length'        => $length,
+            'unsigned'      => str_contains($tableColumn['column_type'], 'unsigned'),
+            'fixed'         => $fixed,
             'default'       => $columnDefault,
             'notnull'       => $tableColumn['null'] !== 'YES',
-            'scale'         => null,
-            'precision'     => null,
-            'autoincrement' => strpos($tableColumn['extra'], 'auto_increment') !== false,
-            'comment'       => isset($tableColumn['comment']) && $tableColumn['comment'] !== ''
-                ? $tableColumn['comment']
-                : null,
+            'scale'         => $scale,
+            'precision'     => $precision,
+            'autoincrement' => str_contains($tableColumn['extra'], 'auto_increment'),
+            'values'        => $values,
         ];
 
-        if ($scale !== null && $precision !== null) {
-            $options['scale']     = (int) $scale;
-            $options['precision'] = (int) $precision;
+        if ($tableColumn['comment'] !== null) {
+            $options['comment'] = $tableColumn['comment'];
         }
 
         $column = new Column($tableColumn['field'], Type::getType($type), $options);
-
-        if (isset($tableColumn['characterset'])) {
-            $column->setPlatformOption('charset', $tableColumn['characterset']);
-        }
-
-        if (isset($tableColumn['collation'])) {
-            $column->setPlatformOption('collation', $tableColumn['collation']);
-        }
+        $column->setPlatformOption('charset', $tableColumn['characterset']);
+        $column->setPlatformOption('collation', $tableColumn['collation']);
 
         return $column;
     }
 
+    /** @return list<string> */
+    private function parseEnumExpression(string $expression): array
+    {
+        $result = preg_match_all("/'([^']*(?:''[^']*)*)'/", $expression, $matches);
+        assert($result !== false);
+
+        return array_map(
+            static fn (string $match): string => strtr($match, ["''" => "'"]),
+            $matches[1],
+        );
+    }
+
     /**
      * Return Doctrine/Mysql-compatible column default values for MariaDB 10.2.7+ servers.
      *
@@ -305,7 +244,7 @@ class MySQLSchemaManager extends AbstractSchemaManager
      *
      * @param string|null $columnDefault default value as stored in information_schema for MariaDB >= 10.2.7
      */
-    private function getMariaDb1027ColumnDefault(MariaDb1027Platform $platform, ?string $columnDefault): ?string
+    private function getMariaDBColumnDefault(MariaDBPlatform $platform, ?string $columnDefault): ?string
     {
         if ($columnDefault === 'NULL' || $columnDefault === null) {
             return null;
@@ -315,49 +254,43 @@ class MySQLSchemaManager extends AbstractSchemaManager
             return strtr($matches[1], self::MARIADB_ESCAPE_SEQUENCES);
         }
 
-        switch ($columnDefault) {
-            case 'current_timestamp()':
-                return $platform->getCurrentTimestampSQL();
-
-            case 'curdate()':
-                return $platform->getCurrentDateSQL();
-
-            case 'curtime()':
-                return $platform->getCurrentTimeSQL();
-        }
-
-        return $columnDefault;
+        return match ($columnDefault) {
+            'current_timestamp()' => $platform->getCurrentTimestampSQL(),
+            'curdate()' => $platform->getCurrentDateSQL(),
+            'curtime()' => $platform->getCurrentTimeSQL(),
+            default => $columnDefault,
+        };
     }
 
     /**
-     * {@inheritdoc}
+     * {@inheritDoc}
      */
-    protected function _getPortableTableForeignKeysList($tableForeignKeys)
+    protected function _getPortableTableForeignKeysList(array $rows): array
     {
         $list = [];
-        foreach ($tableForeignKeys as $value) {
-            $value = array_change_key_case($value, CASE_LOWER);
-            if (! isset($list[$value['constraint_name']])) {
-                if (! isset($value['delete_rule']) || $value['delete_rule'] === 'RESTRICT') {
-                    $value['delete_rule'] = null;
+        foreach ($rows as $row) {
+            $row = array_change_key_case($row, CASE_LOWER);
+            if (! isset($list[$row['constraint_name']])) {
+                if (! isset($row['delete_rule']) || $row['delete_rule'] === 'RESTRICT') {
+                    $row['delete_rule'] = null;
                 }
 
-                if (! isset($value['update_rule']) || $value['update_rule'] === 'RESTRICT') {
-                    $value['update_rule'] = null;
+                if (! isset($row['update_rule']) || $row['update_rule'] === 'RESTRICT') {
+                    $row['update_rule'] = null;
                 }
 
-                $list[$value['constraint_name']] = [
-                    'name' => $value['constraint_name'],
+                $list[$row['constraint_name']] = [
+                    'name' => $this->getQuotedIdentifierName($row['constraint_name']),
                     'local' => [],
                     'foreign' => [],
-                    'foreignTable' => $value['referenced_table_name'],
-                    'onDelete' => $value['delete_rule'],
-                    'onUpdate' => $value['update_rule'],
+                    'foreignTable' => $row['referenced_table_name'],
+                    'onDelete' => $row['delete_rule'],
+                    'onUpdate' => $row['update_rule'],
                 ];
             }
 
-            $list[$value['constraint_name']]['local'][]   = $value['column_name'];
-            $list[$value['constraint_name']]['foreign'][] = $value['referenced_column_name'];
+            $list[$row['constraint_name']]['local'][]   = $row['column_name'];
+            $list[$row['constraint_name']]['foreign'][] = $row['referenced_column_name'];
         }
 
         return parent::_getPortableTableForeignKeysList($list);
@@ -366,7 +299,7 @@ class MySQLSchemaManager extends AbstractSchemaManager
     /**
      * {@inheritDoc}
      */
-    protected function _getPortableTableForeignKeyDefinition($tableForeignKey): ForeignKeyConstraint
+    protected function _getPortableTableForeignKeyDefinition(array $tableForeignKey): ForeignKeyConstraint
     {
         return new ForeignKeyConstraint(
             $tableForeignKey['local'],
@@ -380,13 +313,19 @@ class MySQLSchemaManager extends AbstractSchemaManager
         );
     }
 
-    public function createComparator(): Comparator
+    /** @throws Exception */
+    public function createComparator(/* ComparatorConfig $config = new ComparatorConfig() */): Comparator
     {
         return new MySQL\Comparator(
-            $this->_platform,
-            new CachingCollationMetadataProvider(
-                new ConnectionCollationMetadataProvider($this->_conn),
+            $this->platform,
+            new CachingCharsetMetadataProvider(
+                new ConnectionCharsetMetadataProvider($this->connection),
             ),
+            new CachingCollationMetadataProvider(
+                new ConnectionCollationMetadataProvider($this->connection),
+            ),
+            $this->getDefaultTableOptions(),
+            func_num_args() > 0 ? func_get_arg(0) : new ComparatorConfig(),
         );
     }
 
@@ -400,20 +339,33 @@ WHERE TABLE_SCHEMA = ?
 ORDER BY TABLE_NAME
 SQL;
 
-        return $this->_conn->executeQuery($sql, [$databaseName]);
+        return $this->connection->executeQuery($sql, [$databaseName]);
     }
 
     protected function selectTableColumns(string $databaseName, ?string $tableName = null): Result
     {
-        $sql = 'SELECT';
+        // The schema name is passed multiple times as a literal in the WHERE clause instead of using a JOIN condition
+        // in order to avoid performance issues on MySQL older than 8.0 and the corresponding MariaDB versions
+        // caused by https://bugs.mysql.com/bug.php?id=81347
+        $conditions = ['c.TABLE_SCHEMA = ?', 't.TABLE_SCHEMA = ?'];
+        $params     = [$databaseName, $databaseName];
 
-        if ($tableName === null) {
-            $sql .= ' c.TABLE_NAME,';
+        if ($tableName !== null) {
+            $conditions[] = 't.TABLE_NAME = ?';
+            $params[]     = $tableName;
         }
 
-        $sql .= <<<'SQL'
+        $sql = sprintf(
+            <<<'SQL'
+SELECT
+       c.TABLE_NAME,
        c.COLUMN_NAME        AS field,
-       c.COLUMN_TYPE        AS type,
+       %s                   AS type,
+       c.COLUMN_TYPE,
+       c.CHARACTER_MAXIMUM_LENGTH,
+       c.CHARACTER_OCTET_LENGTH,
+       c.NUMERIC_PRECISION,
+       c.NUMERIC_SCALE,
        c.IS_NULLABLE        AS `null`,
        c.COLUMN_KEY         AS `key`,
        c.COLUMN_DEFAULT     AS `default`,
@@ -424,41 +376,20 @@ SQL;
 FROM information_schema.COLUMNS c
     INNER JOIN information_schema.TABLES t
         ON t.TABLE_NAME = c.TABLE_NAME
-SQL;
+ WHERE %s
+   AND t.TABLE_TYPE = 'BASE TABLE'
+ORDER BY c.TABLE_NAME,
+         c.ORDINAL_POSITION
+SQL,
+            $this->platform->getColumnTypeSQLSnippet('c', $databaseName),
+            implode(' AND ', $conditions),
+        );
 
-        // The schema name is passed multiple times as a literal in the WHERE clause instead of using a JOIN condition
-        // in order to avoid performance issues on MySQL older than 8.0 and the corresponding MariaDB versions
-        // caused by https://bugs.mysql.com/bug.php?id=81347
-        $conditions = ['c.TABLE_SCHEMA = ?', 't.TABLE_SCHEMA = ?', "t.TABLE_TYPE = 'BASE TABLE'"];
-        $params     = [$databaseName, $databaseName];
-
-        if ($tableName !== null) {
-            $conditions[] = 't.TABLE_NAME = ?';
-            $params[]     = $tableName;
-        }
-
-        $sql .= ' WHERE ' . implode(' AND ', $conditions) . ' ORDER BY ORDINAL_POSITION';
-
-        return $this->_conn->executeQuery($sql, $params);
+        return $this->connection->executeQuery($sql, $params);
     }
 
     protected function selectIndexColumns(string $databaseName, ?string $tableName = null): Result
     {
-        $sql = 'SELECT';
-
-        if ($tableName === null) {
-            $sql .= ' TABLE_NAME,';
-        }
-
-        $sql .= <<<'SQL'
-        NON_UNIQUE  AS Non_Unique,
-        INDEX_NAME  AS Key_name,
-        COLUMN_NAME AS Column_Name,
-        SUB_PART    AS Sub_Part,
-        INDEX_TYPE  AS Index_Type
-FROM information_schema.STATISTICS
-SQL;
-
         $conditions = ['TABLE_SCHEMA = ?'];
         $params     = [$databaseName];
 
@@ -467,53 +398,64 @@ SQL;
             $params[]     = $tableName;
         }
 
-        $sql .= ' WHERE ' . implode(' AND ', $conditions) . ' ORDER BY SEQ_IN_INDEX';
+        $sql = sprintf(
+            <<<'SQL'
+SELECT
+        TABLE_NAME,
+        NON_UNIQUE  AS Non_Unique,
+        INDEX_NAME  AS Key_name,
+        COLUMN_NAME AS Column_Name,
+        SUB_PART    AS Sub_Part,
+        INDEX_TYPE  AS Index_Type
+FROM information_schema.STATISTICS
+WHERE %s
+ORDER BY TABLE_NAME,
+         SEQ_IN_INDEX
+SQL,
+            implode(' AND ', $conditions),
+        );
 
-        return $this->_conn->executeQuery($sql, $params);
+        return $this->connection->executeQuery($sql, $params);
     }
 
     protected function selectForeignKeyColumns(string $databaseName, ?string $tableName = null): Result
     {
-        $sql = 'SELECT DISTINCT';
-
-        if ($tableName === null) {
-            $sql .= ' k.TABLE_NAME,';
-        }
-
-        $sql .= <<<'SQL'
-            k.CONSTRAINT_NAME,
-            k.COLUMN_NAME,
-            k.REFERENCED_TABLE_NAME,
-            k.REFERENCED_COLUMN_NAME,
-            k.ORDINAL_POSITION /*!50116,
-            c.UPDATE_RULE,
-            c.DELETE_RULE */
-FROM information_schema.key_column_usage k /*!50116
-INNER JOIN information_schema.referential_constraints c
-ON c.CONSTRAINT_NAME = k.CONSTRAINT_NAME
-AND c.TABLE_NAME = k.TABLE_NAME */
-SQL;
-
-        $conditions = ['k.TABLE_SCHEMA = ?'];
-        $params     = [$databaseName];
+        // The schema name is passed multiple times in the WHERE clause instead of using a JOIN condition
+        // in order to avoid performance issues on MySQL older than 8.0 and the corresponding MariaDB versions
+        // caused by https://bugs.mysql.com/bug.php?id=81347
+        $conditions = ['k.TABLE_SCHEMA = ?', 'c.CONSTRAINT_SCHEMA = ?'];
+        $params     = [$databaseName, $databaseName];
 
         if ($tableName !== null) {
             $conditions[] = 'k.TABLE_NAME = ?';
             $params[]     = $tableName;
         }
 
-        $conditions[] = 'k.REFERENCED_COLUMN_NAME IS NOT NULL';
+        $sql = sprintf(
+            <<<'SQL'
+SELECT
+            k.TABLE_NAME,
+            k.CONSTRAINT_NAME,
+            k.COLUMN_NAME,
+            k.REFERENCED_TABLE_NAME,
+            k.REFERENCED_COLUMN_NAME,
+            k.ORDINAL_POSITION,
+            c.UPDATE_RULE,
+            c.DELETE_RULE
+FROM information_schema.key_column_usage k
+INNER JOIN information_schema.referential_constraints c
+ON c.CONSTRAINT_NAME = k.CONSTRAINT_NAME
+AND c.TABLE_NAME = k.TABLE_NAME
+WHERE %s
+AND k.REFERENCED_COLUMN_NAME IS NOT NULL
+ORDER BY k.TABLE_NAME,
+         k.CONSTRAINT_NAME,
+         k.ORDINAL_POSITION
+SQL,
+            implode(' AND ', $conditions),
+        );
 
-        $sql .= ' WHERE ' . implode(' AND ', $conditions)
-            // The schema name is passed multiple times in the WHERE clause instead of using a JOIN condition
-            // in order to avoid performance issues on MySQL older than 8.0 and the corresponding MariaDB versions
-            // caused by https://bugs.mysql.com/bug.php?id=81347.
-            // Use a string literal for the database name since the internal PDO SQL parser
-            // cannot recognize parameter placeholders inside conditional comments
-            . ' /*!50116 AND c.CONSTRAINT_SCHEMA = ' . $this->_conn->quote($databaseName) . ' */'
-            . ' ORDER BY k.ORDINAL_POSITION';
-
-        return $this->_conn->executeQuery($sql, $params);
+        return $this->connection->executeQuery($sql, $params);
     }
 
     /**
@@ -521,33 +463,15 @@ SQL;
      */
     protected function fetchTableOptionsByTable(string $databaseName, ?string $tableName = null): array
     {
-        $sql = <<<'SQL'
-    SELECT t.TABLE_NAME,
-           t.ENGINE,
-           t.AUTO_INCREMENT,
-           t.TABLE_COMMENT,
-           t.CREATE_OPTIONS,
-           t.TABLE_COLLATION,
-           ccsa.CHARACTER_SET_NAME
-      FROM information_schema.TABLES t
-        INNER JOIN information_schema.COLLATION_CHARACTER_SET_APPLICABILITY ccsa
-            ON ccsa.COLLATION_NAME = t.TABLE_COLLATION
-SQL;
-
-        $conditions = ['t.TABLE_SCHEMA = ?'];
-        $params     = [$databaseName];
+        $sql = $this->platform->fetchTableOptionsByTable($tableName !== null);
 
+        $params = [$databaseName];
         if ($tableName !== null) {
-            $conditions[] = 't.TABLE_NAME = ?';
-            $params[]     = $tableName;
+            $params[] = $tableName;
         }
 
-        $conditions[] = "t.TABLE_TYPE = 'BASE TABLE'";
-
-        $sql .= ' WHERE ' . implode(' AND ', $conditions);
-
-        /** @var array<string,array<string,mixed>> $metadata */
-        $metadata = $this->_conn->executeQuery($sql, $params)
+        /** @var array<non-empty-string,array<string,mixed>> $metadata */
+        $metadata = $this->connection->executeQuery($sql, $params)
             ->fetchAllAssociativeIndexed();
 
         $tableOptions = [];
@@ -567,7 +491,7 @@ SQL;
         return $tableOptions;
     }
 
-    /** @return string[]|true[] */
+    /** @return array<string, string>|array<string, true> */
     private function parseCreateOptions(?string $string): array
     {
         $options = [];
@@ -584,4 +508,30 @@ SQL;
 
         return $options;
     }
+
+    /** @throws Exception */
+    private function getDefaultTableOptions(): DefaultTableOptions
+    {
+        if ($this->defaultTableOptions === null) {
+            $row = $this->connection->fetchNumeric(
+                'SELECT @@character_set_database, @@collation_database',
+            );
+
+            assert($row !== false);
+
+            $this->defaultTableOptions = new DefaultTableOptions(...$row);
+        }
+
+        return $this->defaultTableOptions;
+    }
+
+    /** Returns the quoted representation of the given identifier name. */
+    private function getQuotedIdentifierName(?string $identifier): ?string
+    {
+        if ($identifier === null) {
+            return null;
+        }
+
+        return $this->platform->quoteSingleIdentifier($identifier);
+    }
 }
