@@ -4,18 +4,23 @@ declare(strict_types=1);
 
 namespace Doctrine\DBAL\Tests\Schema;
 
+use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\Platforms\MySQLPlatform;
 use Doctrine\DBAL\Platforms\SQLitePlatform;
 use Doctrine\DBAL\Platforms\SQLServerPlatform;
 use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\Exception\UnknownColumnOption;
+use Doctrine\DBAL\Schema\Name\Identifier;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
+use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
 use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 
 class ColumnTest extends TestCase
 {
+    use VerifyDeprecations;
+
     public function testGet(): void
     {
         $column = $this->createColumn();
@@ -31,10 +36,10 @@ class ColumnTest extends TestCase
         self::assertTrue($column->getFixed());
         self::assertEquals('baz', $column->getDefault());
 
-        self::assertEquals(['foo' => 'bar'], $column->getPlatformOptions());
-        self::assertTrue($column->hasPlatformOption('foo'));
-        self::assertEquals('bar', $column->getPlatformOption('foo'));
-        self::assertFalse($column->hasPlatformOption('bar'));
+        self::assertEquals(['charset' => 'utf8'], $column->getPlatformOptions());
+        self::assertTrue($column->hasPlatformOption('charset'));
+        self::assertEquals('utf8', $column->getPlatformOption('charset'));
+        self::assertFalse($column->hasPlatformOption('collation'));
     }
 
     public function testToArray(): void
@@ -53,7 +58,7 @@ class ColumnTest extends TestCase
             'columnDefinition' => null,
             'comment' => '',
             'values' => [],
-            'foo' => 'bar',
+            'charset' => 'utf8',
         ];
 
         self::assertSame($expected, $this->createColumn()->toArray());
@@ -81,26 +86,26 @@ class ColumnTest extends TestCase
 
     public function createColumn(): Column
     {
-        $options = [
-            'length' => 200,
-            'precision' => 5,
-            'scale' => 2,
-            'unsigned' => true,
-            'notnull' => false,
-            'fixed' => true,
-            'default' => 'baz',
-            'platformOptions' => ['foo' => 'bar'],
-        ];
-
-        $string = Type::getType(Types::STRING);
-
-        return new Column('foo', $string, $options);
+        return Column::editor()
+            ->setUnquotedName('foo')
+            ->setTypeName(Types::STRING)
+            ->setLength(200)
+            ->setPrecision(5)
+            ->setScale(2)
+            ->setUnsigned(true)
+            ->setNotNull(false)
+            ->setFixed(true)
+            ->setDefaultValue('baz')
+            ->setCharset('utf8')
+            ->create();
     }
 
     public function testQuotedColumnName(): void
     {
-        $string = Type::getType(Types::STRING);
-        $column = new Column('`bar`', $string, []);
+        $column = Column::editor()
+            ->setQuotedName('bar')
+            ->setTypeName(Types::STRING)
+            ->create();
 
         $mysqlPlatform  = new MySQLPlatform();
         $sqlitePlatform = new SQLitePlatform();
@@ -109,7 +114,10 @@ class ColumnTest extends TestCase
         self::assertEquals('`bar`', $column->getQuotedName($mysqlPlatform));
         self::assertEquals('"bar"', $column->getQuotedName($sqlitePlatform));
 
-        $column = new Column('[bar]', $string);
+        $column = Column::editor()
+            ->setQuotedName('bar')
+            ->setTypeName(Types::STRING)
+            ->create();
 
         $sqlServerPlatform = new SQLServerPlatform();
 
@@ -139,7 +147,10 @@ class ColumnTest extends TestCase
 
     public function testColumnComment(): void
     {
-        $column = new Column('bar', Type::getType(Types::STRING));
+        $column = Column::editor()
+            ->setUnquotedName('bar')
+            ->setType(Type::getType(Types::STRING))
+            ->create();
         self::assertSame('', $column->getComment());
 
         $column->setComment('foo');
@@ -149,4 +160,50 @@ class ColumnTest extends TestCase
         self::assertArrayHasKey('comment', $columnArray);
         self::assertEquals('foo', $columnArray['comment']);
     }
+
+    /** @throws Exception */
+    public function testEmptyName(): void
+    {
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6646');
+
+        new Column('', Type::getType(Types::INTEGER));
+    }
+
+    /** @throws Exception */
+    public function testQualifiedName(): void
+    {
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6592');
+
+        Column::editor()
+            ->setUnquotedName('t.id')
+            ->setType(Type::getType(Types::INTEGER))
+            ->create();
+    }
+
+    /** @throws Exception */
+    public function testGetObjectName(): void
+    {
+        $column = Column::editor()
+            ->setUnquotedName('id')
+            ->setType(Type::getType(Types::INTEGER))
+            ->create();
+
+        self::assertEquals(Identifier::unquoted('id'), $column->getObjectName()->getIdentifier());
+    }
+
+    public function testSetPlatformOptionJsonb(): void
+    {
+        $column = new Column('jsonb', Type::getType(Types::JSON));
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6939');
+        $column->setPlatformOption('jsonb', true);
+    }
+
+    public function testSetPlatformOptionsJsonb(): void
+    {
+        $column = new Column('jsonb', Type::getType(Types::JSON));
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6939');
+        $column->setPlatformOptions(['jsonb' => true]);
+    }
 }
